/*
KEYW: 3D convex hull
*/

#include <cstdio>
#include <cstring>
#include <cassert>
#include <cmath>
#include <vector>
#include <utility>
using std::pair;
#include <ext/hash_set>
#include <ext/hash_map>

const int DIM = 3;

const double EPS = 1e-9;
inline bool EQ(double a, double b) {return fabs(a - b) < EPS;}
inline bool NE(double a, double b) {return !EQ(a, b);}
inline bool LT(double a, double b) {return a < b - EPS;}
inline bool LE(double a, double b) {return !LT(b, a);}
inline bool GT(double a, double b) {return LT(b, a);}
inline bool GE(double a, double b) {return LE(b, a);}

namespace std {
	using namespace __gnu_cxx;
};

struct vec {
	double c[3];
	vec() {}
	vec(const vec &v) {
		memcpy(c, v.c, sizeof(c));
	}
	vec(double _x, double _y, double _z) {
		c[0] = _x; c[1] = _y; c[2] = _z;
	}

	double &operator [] (const int id) {
		return c[id];
	}


	const double &operator [] (const int id) const {
		return c[id];
	}

	double operator * (const vec &v) const {
		double res = 0;
		for (int i = 0; i < DIM; ++i) res += c[i] * v.c[i];
		return res;
	}

	vec &operator -= (const vec &v) {
		for (int i = 0; i < DIM; ++i) c[i] -= v.c[i];
		return *this;
	}

	vec operator - (const vec &v) const {
		vec res(*this);
		return res -= v;
	}

	vec operator - () const {
		vec res(0, 0, 0);
		return res -= *this;
	}

	vec operator % (const vec &v) const {
		return vec(c[1] * v[2] - c[2] * v[1]
				 , c[2] * v[0] - c[0] * v[2]
				 , c[0] * v[1] - c[1] * v[0]);
	}

	double len() const {
		double res = 0;
		for (int i = 0; i < DIM; ++i) res += c[i] * c[i];
		return res;
	}

	void prnt() const {
		printf("%lf", c[0]);
		for (int i = 1; i < DIM; ++i) {
			printf(" %lf", c[i]);
		}
	}
};

double _S(const vec &p1, const vec &p2, const vec &p3) {
	return ((p2 - p1) % (p3 - p1)).len();
}

const int MAXN = 1 << 10;

int N;
vec pool[MAXN];

inline double S(int id1, int id2, int id3) {
	return _S(pool[id1], pool[id2], pool[id3]);
}

struct face {
	vec norm;
	std::vector <int> pnts;

	double dst(const vec &v) const {
		return norm * (v - pool[pnts[0]]);
	}

	void gen_norm(const vec &v) {
		norm = (pool[pnts[2]] - pool[pnts[0]]) % (pool[pnts[1]] - pool[pnts[0]]);
		if (LT(dst(v), 0.))
			norm = -norm;
	}

	bool operator == (const face &f) const {
		return &f == this;
	}

	void prnt() const {
		printf("norm: "); norm.prnt(); puts("");
		printf("pnts: ");
		for (int i = 0; i < (int) pnts.size(); ++i) {
			printf("(%d) ", pnts[i]);
			pool[pnts[i]].prnt();
			puts("");
		}
	}
};

namespace __gnu_cxx {
	template <>
	struct hash<face> {
		size_t operator () (const face &f) const {
			return 0;
		}
	};
}

typedef std::hash_set <face> HSF;
typedef HSF::iterator HSFI;
typedef std::hash_map <pair <int, int>, pair <HSFI, HSFI> > HME;
typedef HME::iterator HMEI;

HSF faces;
HME edges;

void init_hull() {
	int ids[4] = {0, 1};
	int i;
	for (i = 2; i < N; ++i) {
		if (NE(S(ids[0], ids[1], i), 0.)) {
			ids[2] = i;
			break;
		}
	}
	assert(("points lie in a single line", i != N));

	face base;
	base.pnts = std::vector <int> (ids, ids + 3);
	base.norm = (pool[ids[1]] - pool[ids[0]]) % (pool[ids[2]] - pool[ids[0]]);

	for(++i; i < N; ++i) {
		double dst = base.dst(pool[i]);
		if (NE(dst, 0.)) {
			ids[3] = i;
			break;
		}
	}
	assert(("poins lie in a single plane", i != N));

	base.gen_norm(pool[ids[3]]);
	faces.insert(base);
	for (int i = 2; i >= 0; --i) {
		face f;
		for (int j = 0; j < 4; ++j)
			if (j != i)
				f.pnts.push_back(ids[j]);
		f.gen_norm(pool[ids[i]]);
		faces.insert(f);
	}
}

int main() {
	scanf("%d", &N);

	for (int i = 0; i < N; ++i)
		for (int j = 0; j < DIM; ++j)
			scanf("%lf", &pool[i][j]);

	init_hull();

	for (HSFI it = faces.begin(); it != faces.end(); ++it)
		it->prnt();

	return 0;
}
