/*
FROM: Balkan Olympiad in Informatics (BOI) 2002 day 2
PROB: aliens
KEYW: geometry, convex hull, minimal circle covering all points
*/

#include <cstdio>
#include <cmath>
#include <ext/numeric>

const int MAXN = 1 << 17;
const double EPS = 1e-7;

struct pnt {
	double x, y;
	pnt () {}
	pnt (double _x, double _y) : x (_x), y (_y) {}
	pnt operator + (const pnt &a) const {return pnt (x + a.x, y + a.y);}
	pnt operator - (const pnt &a) const {return pnt (x - a.x, y - a.y);}
	pnt operator * (double a) const {return pnt (x * a, y * a);}
	pnt operator / (double a) const {return pnt (x / a, y / a);}
	double operator * (const pnt &a) const {return x * a.x + y * a.y;}
	double cross (const pnt &a) const {return x * a.y - y * a.x;}
	pnt rot () const {return pnt (-y, x);}
	double sq () {return x * x + y * y;}
	double len () {return hypot (x, y);}
};

int N;
pnt vec[MAXN];
int hid[MAXN], hsz;

double S (const pnt &a, const pnt &b, const pnt &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

bool cmp_ang (int a, int b) {
	static double tmp;
	return fabs (tmp = S (vec[hid[0]], vec[a], vec[b])) < EPS ?
			(vec[a] - vec[hid[0]]).sq () < (vec[b] - vec[hid[0]]).sq ()
			:
			tmp > 0;
			
}

double get_cos (const pnt &a, const pnt &b, const pnt &c) {
	return (a - b) * (c - b) / ((a - b).len () * (c - b).len ());
}

void hull () {
	__gnu_cxx::iota (hid, hid + N, 0);

	int fpi = 0;
	int i;
	for (i = 1; i < N; ++i)
		if (vec[i].y  < vec[fpi].y
		 || vec[i].y == vec[fpi].y
		 && vec[i].x  > vec[fpi].x)
			fpi = i;
	//now swap the first point with the first point from the hull
	hid[fpi] = 0;
	hid[0] = fpi;

	std::sort (hid + 1, hid + N, cmp_ang);
//	for (i = 0; i < N; ++i) printf (" %d", hid[i]); puts ("");

	hsz = 2;
	for (i = 2; i < N; ++i) {
		while (hsz > 1 && S (vec[hid[hsz-2]], vec[hid[hsz-1]], vec[hid[i]]) < EPS) --hsz;
		hid[hsz++] = hid[i];
	}
}

pnt find_center (const pnt &a, const pnt &b, const pnt &c) {
	return (b + c) / 2. + (c - b).rot () * ((b - a) * (c - a) / (b - a).cross (c - a)) / 2.;
}

int main () {
	scanf ("%d", &N);

	int i;
	for (i = 0; i < N; ++i)
		scanf ("%lf %lf", &vec[i].x, &vec[i].y);

	hull ();
/*	for (i = 0; i < hsz; ++i)
		printf ("%lf %lf (%d)\n", vec[hid[i]].x, vec[hid[i]].y, hid[i]);*/

	int lb = 2, rb = hsz;
	double bcos, ccos;
	int Ai = 0, Bi = 1, Ci;//A and B are the base points, C is the current best point
	while (lb != rb) {
		Ci = lb;
		bcos = get_cos (vec[hid[Ai]], vec[hid[Ci]], vec[hid[Bi]]);
		for (i = lb + 1; i != rb; ++i)
			if (bcos < (ccos = get_cos (vec[hid[Ai]], vec[hid[i]], vec[hid[Bi]]))) {
				bcos = ccos;
				Ci = i;
			}
		if (bcos < EPS) {//the angle is >= 90 deg, so we have a 2p circle
			break;
		}
		ccos = get_cos (vec[hid[Ci]], vec[hid[Ai]], vec[hid[Bi]]);
		if (get_cos (vec[hid[Ci]], vec[hid[Ai]], vec[hid[Bi]]) < -EPS) {
			rb = Ci;
			Ai = Ci;
		} else if (get_cos (vec[hid[Ci]], vec[hid[Bi]], vec[hid[Ai]]) < -EPS) {
			lb = Ci + 1;
			Bi = Ci;
		} else {
//			printf ("%d %d %d\n", hid[Ai], hid[Bi], hid[Ci]);
			pnt cen = find_center (vec[hid[Ai]], vec[hid[Bi]], vec[hid[Ci]]);
			printf ("%.10lf\n%.10lf %.10lf\n", (cen - vec[hid[Ai]]).len (), cen.x, cen.y);
			return 0;
		}
	}
	printf ("%.10lf\n%.10lf %.10lf\n", (vec[hid[Ai]] - vec[hid[Bi]]).len () / 2,
		((vec[hid[Ai]] + vec[hid[Bi]]) / 2.).x,
		((vec[hid[Ai]] + vec[hid[Bi]]) / 2.).y);
	

	return 0;
}
