/*
FROM: NOI 2000 round 4
PROB: ulica
KEYW: convex hull, separating two sets of points
*/

#include <cstdio>
#include <cmath>

#include <vector>
#include <algorithm>

const double eps = 1e-9;

struct point {
	int x, y;
	point () {}
	point (int _x, int _y) : x (_x), y (_y) {}
	point operator - (const point &a) const {point ret(x, y); ret.x -= a.x; ret.y -= a.y; return ret;}
	int sq () {return x * x + y * y;}
};

struct pointd {
	double x, y;
	pointd () {}
	pointd (const point &a) : x (a.x), y (a.y) {};
	pointd& operator = (const point &a) {x = a.x; y = a.y; return *this;}
	pointd (double _x, double _y) : x (_x), y (_y) {}
	pointd& operator += (const pointd &a) {x += a.x; y += a.y; return *this;}
	pointd& operator -= (const pointd &a) {x -= a.x; y -= a.y; return *this;}
	pointd& operator /= (double d) {x /= d; y /= d; return *this;}

	pointd operator - (const pointd &a) const {pointd ret = *this; ret -= a; return ret;}
	pointd operator + (const pointd &a) const {pointd ret = *this; ret += a; return ret;}

	double sq () {return x * x + y * y;}
	double len () {return sqrt (sq ());}
	pointd rot () {return pointd (y, -x);}
};

std::vector <point> _gr[2];
std::vector <pointd> gr[2];

int S (const point &a, const point &b, const point &c) {
	return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}

point base;
bool cmp (const point &a, const point &b) {
	static int tmp;
	return (tmp = S (base, a, b)) ?
			tmp > 0 :
			(a - base).sq () > (b - base).sq ();
}

bool _try (std::vector <point>::const_iterator x) {
	return S (*x, *(x + 1), *(x + 2)) <= 0;
}

void hull (std::vector <point> &vec) {
	base = vec[0];
	int bi = 0;
	int i;
	for (i = 1; i < (int)vec.size (); ++i)
		if (vec[i].y < base.y || (vec[i].y == base.y && vec[i].x > base.x)) {
			base = vec[i];
			bi = i;
		}
	vec[bi] = vec[0];
	vec[0] = base;

	std::sort (vec.begin () + 1, vec.end (), cmp);

	std::vector <point> res (vec.begin (), vec.begin () + 2);

	for (i = 2; i < (int)vec.size (); ++i) {
		res.push_back (vec[i]);
		while (_try (res.begin () + res.size () - 3)) {
			res[res.size () - 2] = res.back ();
			res.pop_back ();
		}
	}

	vec = res;
}

void trf (const pointd &a, const pointd &b, pointd &p1, pointd &p2) {
	pointd tmp = (b - a).rot ();
	tmp /= tmp.len ();
	tmp /= 5.;//make it approximately 0.02
	p1 = a + tmp;
	p2 = b + tmp;
}

int trfds (double S) {
	if (fabs (S) < eps)
		return 0;
	return S > 0 ? 1 : -1;
}

int S (const pointd &a, const pointd &b, const pointd &c) {
	return trfds ((b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x));
}

bool tryline (const pointd &p1, const pointd &p2) {
	for (int j = 0; j < 2; ++j) {
		int t = S (p1, p2, gr[j][0]);
		for (int i = 1; i < (int)gr[j].size (); ++i)
			if (S (p1, p2, gr[j][i]) != t) return 0;
	}
	return S (p1, p2, gr[0][0]) != S (p1, p2, gr[1][0]);
}

int main () {
	int a, b;
	while (scanf ("%d %d", &a, &b), a && b)
		_gr[0].push_back (point (a, b));
	while (scanf ("%d %d", &a, &b) == 2)
		_gr[1].push_back (point (a, b));


	hull (_gr[0]);
	hull (_gr[1]);
	gr[0].assign (_gr[0].begin (), _gr[0].end ());
	gr[1].assign (_gr[1].begin (), _gr[1].end ());

	int i, j;
/*	for (i = 0; i < (int)gr[0].size (); ++i) printf ("%lf %lf\n", gr[0][i].x, gr[0][i].y); printf ("---\n");
	for (i = 0; i < (int)gr[1].size (); ++i) printf ("%lf %lf\n", gr[1][i].x, gr[1][i].y);
*/
	pointd p1, p2;
	gr[0].push_back (gr[0].front ());
	gr[1].push_back (gr[1].front ());
	for (j = 0; j < 2; ++j)
		for (i = 0; i < (int)gr[0].size () - 1; ++i) {
			trf (gr[j][i], gr[j][i+1], p1, p2);
//			printf ("%.0lf %.0lf  %.0lf %.0lf -- %lf %lf  %lf %lf\n", gr[j][i].x, gr[j][i].y, gr[j][i+1].x, gr[j][i+1].y,\
			p1.x, p1.y, p2.x, p2.y);

			if (tryline (p1, p2))
				goto end;
		}

	end:;
	if (j != 2)
		printf ("%.2lf %.2lf %.2lf %.2lf\n", p1.x, p1.y, p2.x, p2.y);
	else
		printf ("0 0 0 0\n");

	return 0;
}
